==> goods-center-api-2.9.2-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/sku/CreditsSkuDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.sku;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sunyan on 2018/11/12.
 */
public class CreditsSkuDto implements Serializable {

    private static final long serialVersionUID = 7893449313263893004L;
    //商品skuid
    private Long skuId;
    //换购积分
    private Long marketingCredits;
    //换购人民币
    private Long marketingPrice;

    /**
     * 展示价格
     */
    private Long facePrice;
    /**
     * 原价购买价格
     */
    private Long salePrice;

    /**
     * sku 属性值
     */
    private String attributeValue;

    //属性1:名称 属性2:名称
    private String attributeFormatName;
    /**
     * sku子图(预留)
     */
    private String imgUrl;

    private Integer remaining;

    /** ******优惠券扩展字段（当前正在使用批次的信息）****** */
    /** 当前批次库存. */
    private Long currentStock;

    /** 当前批次初始库存. */
    private Long currentTotalStock;

    /**
     * 总库存
     */
    private Integer totalStock;
    /**
     * 有效期开始
     */
    private Date startDay;

    /**
     * 有效期结束
     */
    private Date endDay;

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public Long getMarketingCredits() {
        return marketingCredits;
    }

    public void setMarketingCredits(Long marketingCredits) {
        this.marketingCredits = marketingCredits;
    }

    public Long getMarketingPrice() {
        return marketingPrice;
    }

    public void setMarketingPrice(Long marketingPrice) {
        this.marketingPrice = marketingPrice;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }

    public Long getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(Long salePrice) {
        this.salePrice = salePrice;
    }

    public String getAttributeValue() {
        return attributeValue;
    }

    public void setAttributeValue(String attributeValue) {
        this.attributeValue = attributeValue;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Integer getRemaining() {
        return remaining;
    }

    public void setRemaining(Integer remaining) {
        this.remaining = remaining;
    }

    public Integer getTotalStock() {
        return totalStock;
    }

    public void setTotalStock(Integer totalStock) {
        this.totalStock = totalStock;
    }

    public Date getStartDay() {
        return startDay;
    }

    public void setStartDay(Date startDay) {
        this.startDay = startDay;
    }

    public Date getEndDay() {
        return endDay;
    }

    public void setEndDay(Date endDay) {
        this.endDay = endDay;
    }

    public Long getCurrentStock() {
        return currentStock;
    }

    public void setCurrentStock(Long currentStock) {
        this.currentStock = currentStock;
    }

    public Long getCurrentTotalStock() {
        return currentTotalStock;
    }

    public void setCurrentTotalStock(Long currentTotalStock) {
        this.currentTotalStock = currentTotalStock;
    }

    public String getAttributeFormatName() {
        return attributeFormatName;
    }

    public void setAttributeFormatName(String attributeFormatName) {
        this.attributeFormatName = attributeFormatName;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> goods-center-api-2.10.14-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/sku/CreditsSkuDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.sku;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sunyan on 2018/11/12.
 */
public class CreditsSkuDto implements Serializable {

    private static final long serialVersionUID = 7893449313263893004L;
    //商品skuid
    private Long skuId;
    //换购积分
    private Long marketingCredits;
    //换购人民币
    private Long marketingPrice;

    /**
     * 展示价格
     */
    private Long facePrice;
    /**
     * 原价购买价格
     */
    private Long salePrice;

    /**
     * sku 属性值
     */
    private String attributeValue;

    //属性1:名称 属性2:名称
    private String attributeFormatName;
    /**
     * sku子图(预留)
     */
    private String imgUrl;

    private Integer remaining;

    /** ******优惠券扩展字段（当前正在使用批次的信息）****** */
    /** 当前批次库存. */
    private Long currentStock;

    /** 当前批次初始库存. */
    private Long currentTotalStock;

    /**
     * 总库存
     */
    private Integer totalStock;
    /**
     * 有效期开始
     */
    private Date startDay;

    /**
     * 有效期结束
     */
    private Date endDay;
    /**
     * 成本价
     */
    private Long costPrice;

    public Long getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(Long costPrice) {
        this.costPrice = costPrice;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public Long getMarketingCredits() {
        return marketingCredits;
    }

    public void setMarketingCredits(Long marketingCredits) {
        this.marketingCredits = marketingCredits;
    }

    public Long getMarketingPrice() {
        return marketingPrice;
    }

    public void setMarketingPrice(Long marketingPrice) {
        this.marketingPrice = marketingPrice;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }

    public Long getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(Long salePrice) {
        this.salePrice = salePrice;
    }

    public String getAttributeValue() {
        return attributeValue;
    }

    public void setAttributeValue(String attributeValue) {
        this.attributeValue = attributeValue;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Integer getRemaining() {
        return remaining;
    }

    public void setRemaining(Integer remaining) {
        this.remaining = remaining;
    }

    public Integer getTotalStock() {
        return totalStock;
    }

    public void setTotalStock(Integer totalStock) {
        this.totalStock = totalStock;
    }

    public Date getStartDay() {
        return startDay;
    }

    public void setStartDay(Date startDay) {
        this.startDay = startDay;
    }

    public Date getEndDay() {
        return endDay;
    }

    public void setEndDay(Date endDay) {
        this.endDay = endDay;
    }

    public Long getCurrentStock() {
        return currentStock;
    }

    public void setCurrentStock(Long currentStock) {
        this.currentStock = currentStock;
    }

    public Long getCurrentTotalStock() {
        return currentTotalStock;
    }

    public void setCurrentTotalStock(Long currentTotalStock) {
        this.currentTotalStock = currentTotalStock;
    }

    public String getAttributeFormatName() {
        return attributeFormatName;
    }

    public void setAttributeFormatName(String attributeFormatName) {
        this.attributeFormatName = attributeFormatName;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
